# PLC module, translated from Bhalla and Iyengar 1999

# Return kinetic parameters, constraints, and vector of volumes in each
# compartment (pL) (1 if gating variable, or in element corresponding to
# kappa)

# Based on Pan 2018 cardiac AP

import numpy as np

def kinetic_parameters(M, include_type2_reactions, dims, V):
    # Set the kinetic rate constants

    num_cols = dims['num_cols']
    num_rows = dims['num_rows']

    fkc = 1e6
    smr = 1e-3

    # transitions in the park/drive model
    # q_12 and q_21 are rates in opposite direction of each other

    # ORDER [q_IPR	q_12	q_23	q_24	q_26	q_45]   # kf
    #       [q_IPR	q_21	q_32	q_42	q_62	q_54]   # kr
    # with average values for q_24 and q_42
    kf = [1240, 3, 150, 10500, 11]      # [=] 1/s
    kr = [88, 69, 1e-4, 4010, 3330]     # [=] 1/s


    k_IPR_main = [0.05, 0.05]      # [=] 1/s I think

    k_kinetic = [k_IPR_main[0]] + kf + [k_IPR_main[1]] + kr

    # CONSTRAINTS
    N_cT = []
    K_C = []

    # volume vector
    # W = list(np.append([1] * num_cols, [V['V_myo']] * num_rows))
    W = [1] * num_cols + [V['V_myo']]*3 + [1]*(num_rows-3)

    return (k_kinetic, N_cT, K_C, W)













